==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/CancelButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelButtonClickEventArgsDescription } from "./CancelButtonClickEventArgsDescription";
/**
 * @hidden
 */
var CancelButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CancelButtonClickEventArgsDescriptionMetadata, _super);
    function CancelButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancelButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (CancelButtonClickEventArgsDescriptionMetadata.a == null) {
            CancelButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancelButtonClickEventArgsDescriptionMetadata.c(CancelButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.k(CancelButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    CancelButtonClickEventArgsDescriptionMetadata.d = function (a) {
        CancelButtonClickEventArgsDescriptionMetadata.b(a);
        a.ad("CancelButtonClickEventArgs", function () { return new CancelButtonClickEventArgsDescription(); });
        a.ac("CancelButtonClickEventArgs", CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.$t = markType(CancelButtonClickEventArgsDescriptionMetadata, 'CancelButtonClickEventArgsDescriptionMetadata');
    CancelButtonClickEventArgsDescriptionMetadata.a = null;
    return CancelButtonClickEventArgsDescriptionMetadata;
}(Base));
export { CancelButtonClickEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/CancelButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelButtonClickEventArgsDescription } from "./CancelButtonClickEventArgsDescription";
/**
 * @hidden
 */
var CancelButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CancelButtonClickEventArgsDescriptionMetadata, _super);
    function CancelButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancelButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (CancelButtonClickEventArgsDescriptionMetadata.a == null) {
            CancelButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancelButtonClickEventArgsDescriptionMetadata.c(CancelButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.k(CancelButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    CancelButtonClickEventArgsDescriptionMetadata.d = function (a) {
        CancelButtonClickEventArgsDescriptionMetadata.b(a);
        a.ae("CancelButtonClickEventArgs", function () { return new CancelButtonClickEventArgsDescription(); });
        a.ad("CancelButtonClickEventArgs", CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.$t = markType(CancelButtonClickEventArgsDescriptionMetadata, 'CancelButtonClickEventArgsDescriptionMetadata');
    CancelButtonClickEventArgsDescriptionMetadata.a = null;
    return CancelButtonClickEventArgsDescriptionMetadata;
}(Base));
export { CancelButtonClickEventArgsDescriptionMetadata };
